#if !defined(_DMA_LIB_DEFS_)

#define _DMA_LIB_DEFS_

#define DMA_CTRL (unsigned int *)0xF9000100 /* On prend l'adresse de 
					       l'output register 16 bits */

/* Les 4 bits X00000 sont utilises pour jouer avec le DMA */
#define DMA_MASK  0xF00000

#define DMA_RESET 0x0  /* clear les compteurs */
#define DMA_START_0 0x100000  /* Start DMA 0 */
#define DMA_START_1 0x200000  /* start DMA 1 */
#define DMA_MODE_1 0x400000   /* Mode Fly-by no Burst
			       000000 = Reset
			       400000 = Fly-by no burst, compte DMAA
			       800000 = Fly-by burst, compte SYSCLK
			       C00000 = Fly-by burst, compte front montant
			                DMADXFER
			       */
#define DMA_MODE_2 0x800000
#define NO_BURST DMA_MODE_1
#define BURST_SYSCLK DMA_MODE_2
#define BURST_DMADXFER (DMA_MODE_1|DMA_MODE_2 )

/* Channel 0 is for FAST buffer, Channel 1 for SLOW buffer */
/* DMA Status Register */

#define DMA_FAST_END 0x80000000
#define DMA_SLOW_END 0x40000000

/* DMA Control Register */

#define DMA_ENABLE    0x80000000
#define DMA_IT_ENABLE 0x40000000
#define DMA_TO_MEM    0x20000000
#define DMA_INTERNAL  0x10000000
#define DMA_WIDTH32   0x08000000
#define DMA_DEST_INCR 0x02000000
#define DMA_SRCE_INCR 0x01000000
#define DMA_BUS_PRIOR 0x00800000
#define DMA_FLYBY     0x00200000
#define DMA_STUP_3    0x00180000
#define DMA_WAIT_63   0x0007E000
#define DMA_PHC_7     0x00001C00
#define DMA_ETD       0x00000200    /* programmed as TC output pin */
#define DMA_TCE       0x00000100
#define DMA_CHAIN     0x00000080
#define DMA_BURST     0x00000040
#define DMA_ECE       0x00000020
#define DMA_TCD       0x00000010

u_int32 set_dmacr_fast() ;
u_int32 set_dmada_fast() ;
u_int32 set_dmact_fast() ;
u_int32 set_dmacr_slow() ;
u_int32 set_dmada_slow() ;
u_int32 set_dmact_slow() ;
u_int32 set_dmasr() ;
u_int32 get_dmacr_fast() ;
u_int32 get_dmada_fast() ;
u_int32 get_dmact_fast() ;
u_int32 get_dmacr_slow() ;
u_int32 get_dmada_slow() ;
u_int32 get_dmact_slow() ;
u_int32 get_dmasr() ;

void dma_setup( void ) ;
void dma_set_fast( u_int32 *buff, int nwords ) ;
void dma_wait_fast( void ) ;
void dma_start_fast( void ) ;
void dma_stop_fast( void ) ;
void dma_set_slow( u_int32 *buff, int nwords ) ;
void dma_wait_slow( void ) ;
void dma_start_slow( void ) ;
void dma_stop_slow( void ) ;

#endif
